@@ -14,7 +14,9 @@
                ;; Respect the syntax text properties of presentation.
                (set (make-local-variable 'parse-sexp-lookup-properties) t)
                (add-hook 'after-change-functions
-                         'slime-after-change-function 'append t)))
+                         'slime-after-change-function 'append t)
+               (add-to-list 'yank-handled-properties 
+                            '(slime-repl-presentation . slime-yank-presentations-handler))))
    (add-hook 'slime-event-hooks 'slime-dispatch-presentation-event)
    (setq slime-write-string-function 'slime-presentation-write)
    (add-hook 'slime-connected-hook 'slime-presentations-on-connected)
@@ -55,6 +57,12 @@
   (cl-pushnew '(slime-repl-result-face . t) text-property-default-nonsticky
               :test 'equal))
 
+(defun slime-yank-presentations-handler (category start end)
+  (unless (eq major-mode 'slime-repl-mode)
+    (let ((inhibit-modification-hooks t))
+      (set-text-properties start end nil))
+    t))
+
 (make-variable-buffer-local
  (defvar slime-presentation-start-to-point (make-hash-table)))
 
